#!/bin/bash

#---( Slackware Build Script
#---( Build Script written for DejaGNU
#---( Source URL: ftp://mirrors.kernel.org/gnu/dejagnu/dejagnu-1.4.4.tar.gz
#---( Build script by R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Saturday, October 14, 2006.


#------------------( Set Package Name & Version )


soft='dejagnu'
softversion='1.4.4'
packageversion='1rsa'


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;


export CFLAGS="-O2 -march=$arch -mtune=$cpu" 


#------------------( Configure, Make And Install The Software )


cd $src

./configure --prefix=/usr \
--bindir=/usr/bin \
--mandir=/usr/man \
--infodir=/usr/info

make
make check
make overview.ps
make overview.pdf
make install DESTDIR=$dest



#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)

( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)


#------------------( Compress Man Pages and Info Pages and Move To Correct Location )


( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

( cd $dest/usr/info
  find . -name "*.info" | xargs gzip -9
  rm -f dir
)


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion
mkdir -p $dest/usr/doc/$soft-$softversion/html

cp -a \
  AUTHORS COPYING CONVENTIONS COPYRIGHT AUTHORS NEWS README INSTALL \
  $dest/usr/doc/$soft-$softversion
cp $src/doc/*.pdf $dest/usr/doc/$soft-$softversion
cp $src/doc/*.ps $dest/usr/doc/$soft-$softversion
cp $src/doc/*.rtf $dest/usr/doc/$soft-$softversion
cp $src/doc/html/*.html $dest/usr/doc/$soft-$softversion/html


#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh
chmod -x $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
dejagnu: DejaGnu (A framework for testing other programs)
dejagnu: 
dejagnu: Its purpose is to provide a single front end for all tests. Think of
dejagnu: it as a custom library of Tcl procedures crafted to support writing a
dejagnu: test harness. A test harness is the testing infrastructure that is
dejagnu: created to support a specific program or tool. Each program can have
dejagnu: multiple test suites, all supported by a single test harness. DejaGnu
dejagnu: is written in Expect, which in turn uses Tcl.
dejagnu: 
dejagnu: 
dejagnu: Package created by R S Ananda Murthy on a Slackware-11.0 system.
EOF


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5